package com.zg.project.information.mapper;

import java.util.List;
import com.zg.project.information.domain.StockOutType;

/**
 * 出库类型Mapper接口
 * 
 * @author zg
 * @date 2025-06-09
 */
public interface StockOutTypeMapper 
{
    /**
     * 查询出库类型
     * 
     * @param id 出库类型主键
     * @return 出库类型
     */
    public StockOutType selectStockOutTypeById(Long id);

    /**
     * 查询出库类型列表
     * 
     * @param stockOutType 出库类型
     * @return 出库类型集合
     */
    public List<StockOutType> selectStockOutTypeList(StockOutType stockOutType);

    /**
     * 新增出库类型
     * 
     * @param stockOutType 出库类型
     * @return 结果
     */
    public int insertStockOutType(StockOutType stockOutType);

    /**
     * 修改出库类型
     * 
     * @param stockOutType 出库类型
     * @return 结果
     */
    public int updateStockOutType(StockOutType stockOutType);

    /**
     * 删除出库类型
     * 
     * @param id 出库类型主键
     * @return 结果
     */
    public int deleteStockOutTypeById(Long id);

    /**
     * 批量删除出库类型
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteStockOutTypeByIds(Long[] ids);
}
